@@ -1,5 +1,4 @@
 import logging
-import os
 from typing import Iterable, List
 
 from grimp.application.ports import modulefinder
@@ -84,7 +83,7 @@ class ModuleFinder(modulefinder.AbstractModuleFinder):
         internal_filename_and_path_without_extension = internal_filename_and_path[1:-3]
         components = [
             package_name
-        ] + internal_filename_and_path_without_extension.split(os.sep)
+        ] + internal_filename_and_path_without_extension.split(self.file_system.sep)
         if components[-1] == "__init__":
             components.pop()
         return ".".join(components)
